Learn R Programming

deliberr (version 0.1.0)

format_dri_survey: Format DRI survey

Description

format_dri_survey helps transform raw survey data into useful objects for further manipulation with deliberr

Usage

format_dri_survey(
  survey_info = list(type = NA_character_, order = NA_integer_, statement =
    NA_character_, name = NA_character_, scale_max = NA_integer_, q_method = NA)
)

Value

A list of survey info, including name, considerations

data, policies data, scale_max or the upper bound of Likert-scale survey questions, and q_method which flags whether the survey uses Q methodology

Arguments

survey_info

survey information needed to format DRI survey

See Also

surveys for raw survey data formatting

Examples

Run this code
dri_survey <- format_dri_survey(surveys[surveys$name == "acp", ])

dri_survey$name
dri_survey$considerations

Run the code above in your browser using DataLab