Learn R Programming

deliberr (version 0.1.0)

get_dri_ic: Get DRI Intersubjective Consistency (IC)

Description

get_dri_ic calculates the intersubjective consistency (IC) between deliberation participants using their DRI survey responses

Usage

get_dri_ic(data)

Value

dataframe with pnums or participant numbers, pnum1 and pnum2, or the unique number of participant 1 and 2, respectively, ccor and pcor, or the correlation between considerations statement ratings and policy preference rankings, respecively, and dj, or the modal orthogonal distance d for a given pair j

Arguments

data

the raw DRI survey response data

See Also

human_data for raw survey response data formatting

Other DRI survey methods: get_dri_alpha(), get_dri_case()

Examples

Run this code

# get post-deliberation (stage_id == 2) data from Zukunft case
data <- human_data[human_data$stage_id == 2 & human_data$case == "Zukunft", ]
get_dri_ic(data)

Run the code above in your browser using DataLab