Learn R Programming

deliberr (version 0.1.0)

get_dri_ind: Get DRI from Individual Participants

Description

get_dri_ind calculates the DRI for each individual participant at a deliberation

Usage

get_dri_ind(ic, adjusted = TRUE)

Value

tibble with pnum as participant number and their respective individual dri

Arguments

ic

dataframe generated by get_dri_ic(data)

adjusted

a logical indicating whether to use the original or adjusted DRI calculation formula

See Also

get_dri_ic() to generate ic parameter

Other IC methods: get_dri()

Examples

Run this code

# get post-deliberation (stage_id == 2) data from Zukunft case
data <- human_data[human_data$stage_id == 2 & human_data$case == "Zukunft", ]

# generate IC
ic <- get_dri_ic(data)

# get individual DRIs
get_dri_ind(ic)

Run the code above in your browser using DataLab