Learn R Programming

deliberr (version 0.1.0)

make_dri_llm_prompts: Make DRI LLM Prompts

Description

make_dri_llm_prompts creates the system and user prompts used for generating LLM DRI survey data

Usage

make_dri_llm_prompts(
  dri_survey,
  role_info = list(uid = NA_character_, role = NA_character_, description =
    NA_character_)
)

Value

a list of lists with four variables: system, considerations, policies, and reason prompts

Arguments

dri_survey

a list of formatted DRI survey questions

role_info

information about a specific role, including unique identifier uid, role name, and role description

See Also

format_dri_survey() for how to format dri_survey

prompts for how prompts are formatted

Other LLM methods: get_dri_llm_response(), get_model_ids()

Examples

Run this code

# get ccps as an example survey
dri_survey <- format_dri_survey(surveys[surveys$name == "ccps",])

# create an example role from scratch
role_info <- list(
  uid = "sur",
  role = "surfer",
  description = "likes the ocean"
)

make_dri_llm_prompts(dri_survey, role_info)

Run the code above in your browser using DataLab