powered by
format_dri_survey helps transform raw survey data into useful objects for further manipulation with deliberr
format_dri_survey
deliberr
format_dri_survey( survey_info = list(type = NA_character_, order = NA_integer_, statement = NA_character_, name = NA_character_, scale_max = NA_integer_, q_method = NA) )
A list of survey info, including name, considerations
name
considerations
data, policies data, scale_max or the upper bound of Likert-scale survey questions, and q_method which flags whether the survey uses Q methodology
policies
scale_max
q_method
survey information needed to format DRI survey
surveys for raw survey data formatting
dri_survey <- format_dri_survey(surveys[surveys$name == "acp", ]) dri_survey$name dri_survey$considerations
Run the code above in your browser using DataLab